package AssociationBlogDiscriminator::CMS;

use strict;

sub dialog_grant_role {
    my ($cb, $app, $terms, $args, $param, $hasher) = @_;

    my $author_id = $app->param('author_id');
    my $blog_id   = $app->param('blog_id');
    my $role_id   = $app->param('role_id');

    my $this_user = $app->user;

PERMCHECK: {
        last PERMCHECK
            if $app->can_do('grant_role_for_all_blogs');
        last PERMCHECK
            if $blog_id
                && $this_user->permissions($blog_id)
                ->can_do('grant_role_for_blog');
        return $app->permission_denied();
    }

    my $type = $app->param('_type');
    my ( $user, $role );
    if ( $author_id && $author_id ne 'PSEUDO' ) {
        $user = MT::Author->load($author_id);
    }
    if ($role_id) {
        require MT::Role;
        $role = MT::Role->load($role_id);
    }

    $$hasher = sub {
        my ( $obj, $row ) = @_;
        $row->{label}       = $row->{name};
        if ($obj->has_column('class') && $obj->class eq 'blog') {
            my $website = MT::Website->load( { id => $obj->parent_id } );
            $row->{label} .= ' (' . $website->name . ')'
        }
        $row->{description} = $row->{nickname} if exists $row->{nickname};
        $row->{disabled}    = 1
            if UNIVERSAL::isa( $obj, 'MT::Role' )
                && (   $obj->has('administer_blog')
                    || $obj->has('administer_website') )
                && !$app->can_do('grant_role_for_all_blogs')
                && !$this_user->permissions($blog_id)
                ->can_do('grant_role_for_blog');
        if (   $app->param('type')
            && $app->param('type') eq 'blog'
            && UNIVERSAL::isa( $obj, 'MT::Role' )
            && $obj->has('administer_website') )
        {
            $row->{disabled} = 1;
        }
        if (   $app->param('type')
            && $app->param('type') eq 'website'
            && UNIVERSAL::isa( $obj, 'MT::Role' )
            && $obj->has('administer_blog')
            && !$obj->has('administer_website') )
        {
            $row->{disabled} = 1;
        }
    };
}

1;
